@@ -63,6 +63,9 @@ class CalendarConnector:
 
 # Singleton class for calendar data access/manipulation
 class Calendar:
+    STATUS_LIST_EVENT = ('TENTATIVE','CONFIRMED','CANCELLED')
+    STATUS_LIST_TODO = ('NEEDS-ACTION','IN-PROCESS','COMPLETED','CANCELLED')
+
     _entry_norep_list_sorted = None
     _entry_rep_list = None
     _todo_list = None
@@ -140,7 +143,7 @@ class Calendar:
             else:
                 cls._entry_norep_list_sorted = None # Clear norep cache, mod'd
 
-        cls._event_set_status_from_info(en, e_inf)
+        cls._entry_set_status_from_info(en, e_inf)
         cls._event_set_location_from_info(en, e_inf)
         if e_inf.categories:
             # Convert to list - to work around bug passing set to old icalendar
@@ -164,8 +167,10 @@ class Calendar:
         # Return a reference to the new entry.
         if e_type==EntryInfo.TYPE_EVENT or (e_type is None and isinstance(exen,iEvent)):
             en = iEvent()
+            en_is_event = True
         elif e_type==EntryInfo.TYPE_TODO or (e_type is None and isinstance(exen,iTodo)):
             en = iTodo()
+            en_is_event = False
         else:
             raise ValueError('Unrecognized iCal entry type')
         en.add('UID', Calendar.gen_uid()) # Required
@@ -178,7 +183,7 @@ class Calendar:
             summ = 'New entry' # fallback summary
         en.add('SUMMARY', summ)
         new_dt_start = None
-        if isinstance(en,iEvent):
+        if en_is_event:
             ex_dt_start = exen['DTSTART'].dt if 'DTSTART' in exen else None
             if dt_start:
                 if ex_dt_start:
@@ -197,6 +202,7 @@ class Calendar:
                 delta = new_dt_start - ex_dt_start
                 new_dt_end = ex_dt_end + delta
                 en.add('DTEND', new_dt_end)
+
         if 'LOCATION' in exen:
             en.add('LOCATION', exen['LOCATION'])
         if e_cats is True:
@@ -207,10 +213,16 @@ class Calendar:
             en.add('CATEGORIES', list(e_cats))
         if 'PRIORITY' in exen:
             en.add('PRIORITY', exen['PRIORITY'])
+        if 'STATUS' in exen:
+            # Only add status if it is valid for entry type
+            sl = cls.STATUS_LIST_EVENT if en_is_event else cls.STATUS_LIST_TODO
+            exen_status = exen['STATUS']
+            if exen_status in sl:
+                en.add('STATUS', exen_status)
         en = cls.calConnector.add_entry(en) # Write to store
         if new_dt_start is not None:
             cls._entry_norep_list_sorted = None # Clear norep cache as modified
-        if isinstance(en,iTodo):
+        if not en_is_event: # is Todo
             cls._todo_list = None # Clear todo cache as modified
         return en
 
@@ -284,7 +296,7 @@ class Calendar:
             clear_norep = True
 
         # Other properties: status (cancelled, tentative, etc.), location
-        cls._event_set_status_from_info(en, e_inf)
+        cls._entry_set_status_from_info(en, e_inf)
         cls._event_set_location_from_info(en, e_inf)
 
         # This needs optimising - some cases cause too much cache flushing !!
@@ -373,13 +385,11 @@ class Calendar:
 
 
     @staticmethod
-    def _event_set_status_from_info(ev:iEvent, e_inf:EntryInfo) -> None:
-        # Set event status (cancelled, tentative etc.) from e_inf.
-        # Only allow known values.
-        if 'STATUS' in ev:
-            del(ev['STATUS'])
-        if e_inf.status in ('TENTATIVE','CONFIRMED','CANCELLED'):
-            ev.add('STATUS', e_inf.status)
+    def _entry_set_status_from_info(en:Union[iEvent,iTodo], e_inf:EntryInfo) -> None:
+        # Set entry status (cancelled, tentative etc.) from e_inf.
+        if 'STATUS' in en:
+            del(en['STATUS'])
+        Calendar._add_status_entry(en, e_inf.status)
 
 
     @staticmethod
@@ -406,16 +416,33 @@ class Calendar:
 
 
     @classmethod
-    def set_toggle_status_entry(cls, event:iEvent, stat:Optional[str]) -> None:
-        # Set event STATUS to stat.
+    def set_toggle_status_entry(cls, entry:Union[iEvent,iTodo], stat:Optional[str]) -> None:
+        # Set entry STATUS to stat & save entry.
         # If STATUS is set and equals stat, toggle it off.
-        if 'STATUS' in event:
-            if stat==event['STATUS']:
+        if 'STATUS' in entry:
+            if stat==entry['STATUS']:
                 stat = None # If on, we toggle it off
-            del(event['STATUS'])
-        if stat in ('TENTATIVE','CONFIRMED','CANCELLED'):
-            event.add('STATUS', stat)
-        cls.calConnector.update_entry(event) # Write to store
+            del(entry['STATUS'])
+        cls._add_status_entry(entry, stat)
+        cls.calConnector.update_entry(entry) # Write to store
+
+
+    @staticmethod
+    def _add_status_entry(entry:Union[iEvent,iTodo], stat:Optional[str]) -> None:
+        # Set entry STATUS to stat.
+        # Assumes entry['STATUS'] does not exist.
+        # Only allows spec'ed values.
+        if stat=='COMPLETED':
+            if 'PERCENT-COMPLETE' in entry:
+                del(entry['PERCENT-COMPLETE']) # Automatically set to 100
+        else:
+            if 'PERCENT-COMPLETE' in entry and entry['PERCENT-COMPLETE']==100:
+                entry['PERCENT-COMPLETE'] = 99 # Stop it being == 100
+            if 'COMPLETED' in entry:
+                del(entry['COMPLETED'])
+        if (isinstance(entry,iEvent) and stat in Calendar.STATUS_LIST_EVENT) or (
+            isinstance(entry,iTodo) and stat in Calendar.STATUS_LIST_TODO):
+                entry.add('STATUS', stat)
 
 
     @classmethod
@@ -630,7 +657,7 @@ class CalendarConnectorCalDAV(CalendarConnector):
             vevent.__conn_entry = ev # Sneakily add ev, for rapid access later
             self.cal.add_component(vevent)
         # ... and todos
-        todos = self.calendar.todos()
+        todos = self.calendar.todos(sort_keys=(), include_completed=True)
         for td in todos:
             vtodo = td.icalendar_instance.walk('VTODO')[0]
             vtodo.__conn_entry = td # Sneakily add td, for rapid access later
