@@ -35,6 +35,8 @@ class EntryInfo:
     rep_byday = None
     rep_bymonthday = None
     rep_exceptions = None
+    categories = None
+    priority = None
 
     TYPE_EVENT=0
     TYPE_TODO=1
@@ -81,3 +83,16 @@ class EntryInfo:
         self.rep_byday = byday # e.g. '-1MO' = last Monday
         self.rep_bymonthday = bymonthday # e.g. '-2' = second to last day
         self.rep_exceptions = except_list
+
+
+    def set_categories(self, catlist:list) -> None:
+        # Set categories for this entry (make it a set, so no repeats)
+        if catlist:
+            self.categories = set(catlist)
+        else:
+            self.categories = None
+
+
+    def set_priority(self, pri:Optional[int]) -> None:
+        # Set priority for this entry
+        self.priority = pri if pri and 0<pri<=9 else None
