@@ -72,6 +72,15 @@ class GUI:
     _box_view_cont = None # type: Gtk.Box
     _eventbox = Gtk.EventBox()
 
+    _menu_elt_fullscreen = None # type: Gtk.Widget
+    _menu_elts_entry = None # type: Tuple[Gtk.Widget,...]
+    _menu_elts_event = None # type: Tuple[Gtk.Widget,...]
+    _menu_elts_stat_event = None # type: Tuple[Gtk.Widget,...]
+    _menu_elts_stat_todo = None # type: Tuple[Gtk.Widget,...]
+
+    _image_leave_fs = Gtk.Image.new_from_icon_name('gtk-leave-fullscreen',Gtk.IconSize.MENU)
+    _image_enter_fs = None # type: Gtk.Widget
+
     date_order = ''
     date_formatting_numeric = ''
     date_formatting_text = ''
@@ -124,9 +133,16 @@ class GUI:
         cls._window.set_hide_titlebar_when_maximized(Config.get_bool('global','hide_titlebar_when_maximized'))
         if Config.get_bool('startup','maximize'):
             cls._window.maximize()
-        cls._is_fullscreen = Config.get_bool('startup','fullscreen')
-        if cls._is_fullscreen:
-            cls._window.fullscreen()
+        cls._menu_elt_fullscreen = cls._builder.get_object('menuelt-fullscreen')
+        cls._image_enter_fs = cls._menu_elt_fullscreen.get_image()
+        if Config.get_bool('startup','fullscreen'):
+            cls.toggle_fullscreen()
+
+        # Get handles to menu items to enable/disable when on/not on an entry
+        cls._menu_elts_entry = cls._get_objs_by_id(('menuelt-cut','menuelt-copy','menuelt-delete','menuelt-set-status'))
+        cls._menu_elts_event = cls._get_objs_by_id(('menuelt-edit-time','menuelt-edit-reps','menuelt-edit-alarm','menuelt-edit-details'))
+        cls._menu_elts_stat_event = cls._get_objs_by_id(('menuelt-status-confirmed','menuelt-status-tentative'))
+        cls._menu_elts_stat_todo = cls._get_objs_by_id(('menuelt-status-needsaction','menuelt-status-inprocess','menuelt-status-completed'))
 
         # Handle SIGINT (e.g. from ctrl+C) etc.
         GLib.unix_signal_add(GLib.PRIORITY_DEFAULT_IDLE, signal.SIGINT, cls.exit)
@@ -150,6 +166,9 @@ class GUI:
             'menuitem_stat_confirmed': lambda a: cls.handler_stat_toggle('CONFIRMED'),
             'menuitem_stat_canceled': lambda a: cls.handler_stat_toggle('CANCELLED'),
             'menuitem_stat_tentative': lambda a: cls.handler_stat_toggle('TENTATIVE'),
+            'menuitem_stat_needsaction': lambda a: cls.handler_stat_toggle('NEEDS-ACTION'),
+            'menuitem_stat_inprocess': lambda a: cls.handler_stat_toggle('IN-PROCESS'),
+            'menuitem_stat_completed': lambda a: cls.handler_stat_toggle('COMPLETED'),
             'menuitem_deleteentry': cls.delete_request,
             'menuitem_switchview': cls.switch_view,
             'menuitem_goto': cls.dialog_goto,
@@ -202,6 +221,12 @@ class GUI:
         GLib.idle_add(cls.init_stage2)
 
 
+    @classmethod
+    def _get_objs_by_id(cls, id_list:Tuple[str,...]) -> Tuple[Gtk.Widget,...]:
+        # Helper function to get a tuple of widgets by id
+        return tuple((cls._builder.get_object(id) for id in id_list))
+
+
     @staticmethod
     def init_cal(task:Gio.Task, src_obj, t_data, cancel:Gio.Cancellable)->None:
         # Wrapper around Calendar.init(), so we can call it in a GTask thread.
@@ -406,7 +431,7 @@ class GUI:
     @classmethod
     def _init_comboboxes(cls) -> None:
         # Connect ComboBox events to handlers for extra features.
-        for cb_id in ('combo_repeat_type','combo_bydaymonth','combo_byday_ord','combo_byday_day','combo_status','combo_todo_list','combo_todo_priority'):
+        for cb_id in ('combo_repeat_type','combo_bydaymonth','combo_byday_ord','combo_byday_day','combo_status','combo_todo_list','combo_todo_priority','combo_todo_status'):
             cb = cls._builder.get_object(cb_id)
             cb.connect('key-press-event', cls._combobox_keypress)
 
@@ -419,6 +444,26 @@ class GUI:
             eb.connect('focus-out-event', cls._focusout_unhighlight)
 
 
+    @classmethod
+    def set_menu_elts(cls, on_event:bool=False, on_todo:bool=False) -> None:
+        # Called from Views as the cursor is moved. Enables/disables/hides
+        # menu items appropriate for the current cursor item.
+        for id in cls._menu_elts_entry:
+            id.set_sensitive(on_event or on_todo)
+        for id in cls._menu_elts_event:
+            id.set_sensitive(on_event)
+        if on_event:
+            for id in cls._menu_elts_stat_event:
+                id.show()
+            for id in cls._menu_elts_stat_todo:
+                id.hide()
+        elif on_todo:
+            for id in cls._menu_elts_stat_event:
+                id.hide()
+            for id in cls._menu_elts_stat_todo:
+                id.show()
+
+
     @classmethod
     def keypress(cls, wid:Gtk.Widget, ev:Gdk.EventKey) -> None:
         # Called whenever a key is pressed/repeated when View in focus
@@ -807,12 +852,15 @@ class GUI:
     @classmethod
     def toggle_fullscreen(cls, *args) -> None:
         # Callback to toggle fullscreen mode on/off (e.g. from menu)
-        # !! to-do: update menu text to reflect state
         cls._is_fullscreen = not cls._is_fullscreen
         if cls._is_fullscreen:
             cls._window.fullscreen()
+            cls._menu_elt_fullscreen.set_label('gtk-leave-fullscreen')
+            cls._menu_elt_fullscreen.set_image(cls._image_leave_fs)
         else:
             cls._window.unfullscreen()
+            cls._menu_elt_fullscreen.set_label('gtk-fullscreen')
+            cls._menu_elt_fullscreen.set_image(cls._image_enter_fs)
 
 
     @classmethod
@@ -1572,7 +1620,7 @@ class EventDialogController:
                         u = u.date()
                     cls.wid_rep_enddt.set_date(u if u>dt else dt)
                     cls.rep_occs_determines_end = False
-            if 'STATUS' in event and event['STATUS'] in ('TENTATIVE','CONFIRMED','CANCELLED'):
+            if 'STATUS' in event and event['STATUS'] in Calendar.STATUS_LIST_EVENT:
                 cls.wid_status.set_active_id(event['STATUS'])
             if 'LOCATION' in event:
                 cls.wid_location.set_text(event['LOCATION'])
@@ -2008,6 +2056,7 @@ class TodoDialogController:
     wid_desc = None # type: Gtk.Entry
     wid_todolist = None # type: Gtk.ComboBoxText
     wid_priority = None # type: Gtk.ComboBoxText
+    wid_status = None # type: Gtk.ComboBoxText
     list_default_cats = None # type: list
 
     @classmethod
@@ -2023,6 +2072,7 @@ class TodoDialogController:
         cls.wid_desc = GUI._builder.get_object('entry_dialogtodo_desc')
         cls._init_todolists()
         cls.wid_priority = GUI._builder.get_object('combo_todo_priority')
+        cls.wid_status = GUI._builder.get_object('combo_todo_status')
 
 
     @classmethod
@@ -2065,6 +2115,7 @@ class TodoDialogController:
         if list_idx==None: # View has not specified a default todo list
             list_idx = 0
         cls.wid_priority.set_active(0)
+        cls.wid_status.set_active(0)
         if todo is not None:
             # existing entry - take values
             cls.wid_desc.set_text(todo['SUMMARY'] if 'SUMMARY' in todo else'')
@@ -2072,6 +2123,10 @@ class TodoDialogController:
             if 'PRIORITY' in todo:
                 p = int(todo['PRIORITY'])
                 cls.wid_priority.set_active(p if 1<=p<=9 else 0)
+            if 'STATUS' in todo:
+                s = todo['STATUS']
+                if s in Calendar.STATUS_LIST_TODO:
+                    cls.wid_status.set_active_id(s)
         elif txt is None:
             cls.wid_desc.set_text('') # clear text
         else:
@@ -2094,7 +2149,8 @@ class TodoDialogController:
     def _get_entryinfo(cls) -> EntryInfo:
         # Decipher entry fields and return info as an EntryInfo object.
         desc = cls.wid_desc.get_text()
-        ei = EntryInfo(type=EntryInfo.TYPE_TODO, desc=desc)
+        stat = cls.wid_status.get_active_id()
+        ei = EntryInfo(type=EntryInfo.TYPE_TODO, desc=desc, status=stat)
         list_idx = cls.wid_todolist.get_active()
         ei.set_categories(cls.list_default_cats[list_idx])
         ei.set_priority(cls.wid_priority.get_active())
