@@ -151,7 +151,7 @@ class View:
 
 
     @staticmethod
-    def entry_text_label(ev:iCal.Event, dt_st:dt_date, dt_end:dt_date) -> Gtk.Label:
+    def entry_text_label(ev:iCal.Event, dt_st:dt_date, dt_end:dt_date, add_location:bool=False) -> Gtk.Label:
         # Returns a GtkLabel with entry summary + icons as content.
         # Used by Week & Year views to display entries.
         lab = Gtk.Label()
@@ -162,7 +162,11 @@ class View:
         endtm = View.entry_endtime(dt_st,dt_end,True)
         icons = View.entry_icons(ev,True)
         d_txt = ev['SUMMARY'] if 'SUMMARY' in ev else ''
-        lab.set_text(u'{:s}{:s}{:s}'.format(d_txt,endtm,icons))
+        if add_location and 'LOCATION' in ev:
+            l_txt = ' (@{:s})'.format(ev['LOCATION'])
+        else:
+            l_txt = ''
+        lab.set_text(u'{:s}{:s}{:s}{:s}'.format(d_txt,endtm,l_txt,icons))
         View.add_event_styles(lab, ev)
         return lab
 
@@ -170,7 +174,7 @@ class View:
     @staticmethod
     def entry_icons(ev:iCal.Event, prefix_space:bool) -> str:
         # Returns string of icons for entry (repeat, alarm...)
-        alarm = u'♫' # alternatives: alarm clock ⏰ (U+23F0), bell 🔔 (U+1F514)
+        alarm = u'♫' # alternatives: alarm clock ⏰ (U+23F0), bell 🕭,🔔 (U+1F56D,U+1F514)
         repeat = u'⟳'
         icons = ''
         if ev.walk('VALARM'):
@@ -211,7 +215,7 @@ class View:
     def add_event_styles(wid:Gtk.Label, ev:iCal.Event) -> None:
         # Adds formatting class to label corresponding to event status.
         # Allows entry to be formatted appropriately by CSS.
-        if 'STATUS' in ev and ev['STATUS'] in ('TENTATIVE','CONFIRMED','CANCELLED'):
+        if 'STATUS' in ev and ev['STATUS'] in Calendar.STATUS_LIST_EVENT:
             ctx = wid.get_style_context()
             ctx.add_class(ev['STATUS'].lower())
 
@@ -353,7 +357,9 @@ class View_DayUnit_Base(View):
 
     # Bullets to use as markers in Week/Year views
     _BULLET = u'•'
-    _BULLET_ALLDAY = u'‣' # alternatives:❖⍟✪⦿❂
+    _BULLET_ALLDAY = u'✦' # alternatives:❖⍟✪⦿❂♦⧫⏣⎔⌾⌘⌑⎊⎈⁕⧓⚫⚭⚙✷✦
+    _BULLET_MULTIDAY_START = u'‣'
+    _BULLET_ONGOING = u'»'
     _BULLET_TODO = u'🅣' # alternative:Ⓣ
 
     @classmethod
@@ -368,7 +374,10 @@ class View_DayUnit_Base(View):
         elif type(ev) is iCal.Todo:
             mark = cls._BULLET_TODO
         elif 'DTEND' in ev:
-            mark = cls._BULLET_ALLDAY
+            if dt_lte(ev['DTEND'].dt, ev['DTSTART'].dt+timedelta(days=1)):
+                mark = cls._BULLET_ALLDAY
+            else:
+                mark = cls._BULLET_MULTIDAY_START
         else:
             mark = cls._BULLET
         lab.set_text(mark)
