@@ -43,6 +43,7 @@ class View_Week(View_DayUnit_Base):
     Config.set_defaults('week_view',{
         'pageleft_datepos': 'left',
         'pageright_datepos': 'right',
+        'show_event_location': 'always',
     })
 
     _day_ent_count = [0]*7 # entry count for each day
@@ -53,6 +54,8 @@ class View_Week(View_DayUnit_Base):
     _target_entry = None
     CURSOR_STYLE = 'weekview_cursor'
 
+    SHOW_LOC_ALWAYS = 1 # constant 'enum' for _show_location flag
+
     @staticmethod
     def view_name() -> str:
         # Return (localised) string to use in menu
@@ -75,6 +78,7 @@ class View_Week(View_DayUnit_Base):
         cls._weekno_label = GUI._builder.get_object('week_label_weekno')
         cls._init_week_widgets()
         cls._init_keymap()
+        cls._init_config()
         return cls._topbox
 
 
@@ -138,6 +142,29 @@ class View_Week(View_DayUnit_Base):
             page_r.pack_start(cls._day_eventbox[i], True, True, 0)
 
 
+    @classmethod
+    def _init_keymap(cls) -> None:
+        # Initialises KEYMAP for class. Called from init() since it needs
+        # to be called after class construction, so that functions exist.
+        cls._KEYMAP = {
+            Gdk.KEY_Up: lambda: cls._cursor_move_up(),
+            Gdk.KEY_Down: lambda: cls._cursor_move_dn(),
+            Gdk.KEY_Right: lambda: cls._cursor_move_rt(),
+            Gdk.KEY_Left: lambda: cls._cursor_move_lt(),
+            Gdk.KEY_space: lambda: cls._cursor_move_today(),
+            Gdk.KEY_Return: lambda: cls.cursor_edit_entry(),
+        }
+
+
+    @classmethod
+    def _init_config(cls) -> None:
+        # Initialisation from config settings.
+        # Set _show_location flag from config.
+        show_loc = Config.get('week_view','show_event_location')
+        map = {'always':cls.SHOW_LOC_ALWAYS, 'never':0}
+        cls._show_location = map[show_loc] if show_loc in map else 0
+
+
     @classmethod
     def _set_label_text(cls) -> None:
         # Sets date and month label text and style classes.
@@ -218,7 +245,7 @@ class View_Week(View_DayUnit_Base):
                 if cls._target_entry is not None and cls._target_entry is occ[0] and dt==View._cursor_date:
                     View._cursor_idx_in_date = cls._day_ent_count[i]
                     cls._target_entry = None
-                cls._add_day_entry_row(occ[0], occ_dt_sta, occ_dt_end, i)
+                cls._add_day_entry_row(occ[0], occ_dt_sta, occ_dt_end, i, cls._show_location)
                 try:
                     occ = next(itr)
                 except StopIteration:
@@ -236,7 +263,7 @@ class View_Week(View_DayUnit_Base):
 
 
     @classmethod
-    def _add_day_entry_row(cls, ev:iCal.Event, dt_st:dt_date, dt_end:dt_date, dayidx:int) -> None:
+    def _add_day_entry_row(cls, ev:iCal.Event, dt_st:dt_date, dt_end:dt_date, dayidx:int, show_loc:bool) -> None:
         # Add Gtk labels for event 'ev', occurrence at time/date from 'dt_st'
         # to 'dt_end', in day 'dayidx' (e.g. 0=Monday if week starts Monday).
         # Used when displaying week contents.
@@ -247,7 +274,7 @@ class View_Week(View_DayUnit_Base):
         ctx.add_class('weekview_marker') # add style for CSS
         row.add(mark_label)
         # Create entry content label & add to row
-        cont_label = cls.entry_text_label(ev, dt_st, dt_end)
+        cont_label = cls.entry_text_label(ev, dt_st, dt_end, add_location=show_loc)
         cont_label.set_hexpand(True) # Also sets hexpand_set to True
         row.add(cont_label)
         cls._day_rows[dayidx].add(row)
@@ -280,6 +307,7 @@ class View_Week(View_DayUnit_Base):
             cls._scroll_to_cursor_in_day = dy # to be read in draw handler
         else:
             cls._scroll_to_cursor_in_day = None
+        GUI.set_menu_elts(on_event=(ecount!=0)) # Enable/disable hide menu items
 
 
     @classmethod
@@ -404,20 +432,6 @@ class View_Week(View_DayUnit_Base):
             cls.redraw(en_changes=False)
 
 
-    @classmethod
-    def _init_keymap(cls) -> None:
-        # Initialises KEYMAP for class. Called from init() since it needs
-        # to be called after class construction, so that functions exist.
-        cls._KEYMAP = {
-            Gdk.KEY_Up: lambda: cls._cursor_move_up(),
-            Gdk.KEY_Down: lambda: cls._cursor_move_dn(),
-            Gdk.KEY_Right: lambda: cls._cursor_move_rt(),
-            Gdk.KEY_Left: lambda: cls._cursor_move_lt(),
-            Gdk.KEY_space: lambda: cls._cursor_move_today(),
-            Gdk.KEY_Return: lambda: cls.cursor_edit_entry(),
-        }
-
-
     @classmethod
     def keypress(cls, wid:Gtk.Widget, ev:Gdk.EventKey) -> None:
         # Handle key press event in Week view.
