@@ -40,7 +40,10 @@ from .pygenda_util import start_end_dts_occ
 
 # Singleton class for Year View
 class View_Year(View_DayUnit_Base):
-    Config.set_defaults('year_view',{})
+    Config.set_defaults('year_view',{
+        'show_event_location': 'always',
+    })
+
     DAY_CLASS = [ 'yearview_day_{}'.format(s) for s in ['mon','tue','wed','thu','fri','sat','sun'] ]
     GRID_COLUMNS = 37
     GRID_ROWS = 12 # One per month
@@ -55,6 +58,8 @@ class View_Year(View_DayUnit_Base):
     _scroll_to_cursor_required = False
     _target_entry = None
 
+    SHOW_LOC_ALWAYS = 1 # constant 'enum' for _show_location flag
+
     @staticmethod
     def view_name() -> str:
         # Return (localised) string to use in menu
@@ -81,6 +86,8 @@ class View_Year(View_DayUnit_Base):
         cls._draw_day_month_labels()
         cls._init_keymap()
         cls._init_grid()
+        cls._init_config()
+
         GUI._builder.get_object('year_grid_events').connect('button_press_event', cls.click_grid)
         GUI._builder.get_object('year_datecontent_events').connect('button_press_event', cls.click_events)
         return cls._topbox
@@ -143,6 +150,15 @@ class View_Year(View_DayUnit_Base):
                 cls._grid_cells.attach(l,d,m,1,1)
 
 
+    @classmethod
+    def _init_config(cls) -> None:
+        # Initialisation from config settings.
+        # Set _show_location flag from config.
+        show_loc = Config.get('year_view','show_event_location')
+        map = {'always':cls.SHOW_LOC_ALWAYS, 'never':0}
+        cls._show_location = map[show_loc] if show_loc in map else 0
+
+
     @classmethod
     def _draw_year(cls) -> None:
         # Draws year - adds formatting classes to cells, labels to some dates.
@@ -282,7 +298,7 @@ class View_Year(View_DayUnit_Base):
             ctx.add_class('yearview_marker') # add style for CSS
             row.add(mark_label)
             # Create entry content label & add to row
-            cont_label = cls.entry_text_label(occ[0],occ_dt_sta,occ_dt_end)
+            cont_label = cls.entry_text_label(occ[0], occ_dt_sta, occ_dt_end, add_location=cls._show_location)
             cont_label.set_hexpand(True) # Also sets hexpand_set to True
             row.add(cont_label)
             cls._date_content.add(row)
@@ -304,6 +320,7 @@ class View_Year(View_DayUnit_Base):
         if cls._date_content_count==0:
             # No entries for day - return
             View._cursor_idx_in_date = 0
+            GUI.set_menu_elts(on_event=False) # Disable menu items
             return
         i = View._cursor_idx_in_date
         if i<0 or i>=cls._date_content_count:
@@ -314,6 +331,7 @@ class View_Year(View_DayUnit_Base):
         ctx.add_class(cls.ENTRY_CURSOR_STYLE)
         cls._last_entry_cursor = i
         cls._scroll_to_cursor_required = True # to be read in draw handler
+        GUI.set_menu_elts(on_event=True) # Enable menu items
 
 
     @classmethod
